import telebox
{% if full %}
from telebox import Bot, ContextBot, StateMachine, ContextStateMachine
{% else %}
from telebox import Bot, ContextBot
{% endif %}
{% if full %}

from {{ app_name }}.states.group import StateGroup
{% endif %}


class Env(telebox.Env):
    bot: Bot
    context_bot: ContextBot
{% if full %}
    state_machine: StateMachine
    context_state_machine: ContextStateMachine
    states: StateGroup
{% endif %}
    # Here you can add additional objects
